Software tests for app_skellington
==================================
Contained is the early stages of unit testing for app_skellington framework.

Usage
-----
Run all tests (cwd is testing directory):

    pytest .

Run test by keyword:

    pytest -k "<test keyword>" .

Run test by directory:

    pytest <dirname>
  
